#
# spec file for package geos
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define uver	3_13_1
Name:           geos
Version:        3.13.1
Release:        1.1
Summary:        Geometry Engine - Open Source
License:        LGPL-2.1-only
URL:            https://libgeos.org
Source0:        https://download.osgeo.org/%{name}/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology
Suite (JTS). As such, it aims to contain the complete functionality of JTS
in C++. This includes all the OpenGIS "Simple Features for SQL" spatial
predicate functions and spatial operators, as well as specific JTS topology
functions such as IsValid().

%package -n libgeos%{uver}
Summary:        Geometry Engine library

%description -n libgeos%{uver}
GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology
Suite (JTS). As such, it aims to contain the complete functionality of JTS
in C++. This includes all the OpenGIS "Simple Features for SQL" spatial
predicate functions and spatial operators, as well as specific JTS topology
functions such as IsValid().

%package -n libgeos_c1
Summary:        C language interface for the GEOS library

%description -n libgeos_c1
This subpackage contains a shared library providing a C linkage
interface for the (C++) GEOS library.

%package devel
Summary:        Development files for GEOS
Requires:       libgeos%{uver} = %{version}-%{release}
Requires:       libgeos_c1 = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description devel
GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology
Suite (JTS). As such, it aims to contain the complete functionality of
JTS in C++. This includes all the OpenGIS "Simple Features for SQL" spatial
predicate functions and spatial operators, as well as specific JTS topology
functions such as IsValid()

This package contains the development files to build applications that
use GEOS.

%prep
%autosetup

%build
%cmake
%cmake_build

%check
# path needs to be exported otherwise unit tests will fail
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
# disable tests for i586 as they fail
%ifnarch %ix86
%ctest
%endif

%install
%cmake_install

%ldconfig_scriptlets -n libgeos%{uver}
%ldconfig_scriptlets -n libgeos_c1

%files
%license COPYING
%{_bindir}/geosop

%files -n libgeos%{uver}
%license COPYING
%{_libdir}/libgeos.so.*

%files -n libgeos_c1
%license COPYING
%{_libdir}/libgeos_c.so.*

%files devel
%license COPYING
%doc NEWS.md README.md
%{_bindir}/geos-config
%{_includedir}/*
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_libdir}/cmake/GEOS
%{_libdir}/cmake/GEOS/geos-*
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}_c.so

%changelog
* Thu Mar 13 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.13.1:
  - See provided NEWS.md for a complete list of changes
* Fri Jan 10 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.13.0:
  - See provided NEWS.md for a complete list of changes
* Mon Jul 29 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.12.2:
  - See provided NEWS.md for a complete list of changes
- Drop old conflicts from package rename that happened years ago
* Tue Nov 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.12.1:
  - See provided NEWS.md for a complete list of changes
- Drop no longer needed geos-add-missing-include.patch
* Thu Mar 30 2023 Martin Pluskal <mpluskal@suse.com>
- Disable testuite on i586
* Wed Mar 29 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add geos-add-missing-include.patch: Add missing #include <cstdint>
* Fri Mar 17 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.11.2:
  * GEOSIntersection: Fix FE_INVALID exception on intersection of disjoint geometries (GH-791, Joris Van den Bossche & Dan Baston)
  * Fix incorrect result from Envelope::disjoint (GH-791, Dan Baston)
  * Fix handling of odd cases in PolygonHoleJoiner (JTS-946, Paul Ramsey, Martin Davis)
  * Support gcc-13 (GH-743, Sergei Trofimovich)
  * Disallow Inf envelopes in Quadtree, avoid inf loop (Paul Ramsey)
  * GEOSUnaryUnion: Fix crash on collection containing empty point (GH-830, Dan Baston)
  * GEOSSTRtree_iterate: Do not return removed items (GH-833, Dan Baston)
  * IndexedFacetDistance: Fix crash with Inf coordinates (GH-821, Dan Baston)
  * HausdorffDistance: Fix crash on collection containing empty point (GH-840, Dan Baston)
  * MaximumInscribedCircle: Fix infinite loop with non-finite coordinates (GH-843, Dan Baston)
  * DistanceOp: Fix crash on collection containing empty point (GH-842, Dan Baston)
  * Guard against non-finite distances in Buffer/OffsetCurve (GH-661, Paul Ramsey)
* Mon Nov 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.11.1:
  * Remove spurious version from --libs geos-config options
  * Fix PreparedGeometry to avoid crashes with EMPTY elements in input (GH-678, Martin Davis)
  * Fix LineSegment.orientationIndex(LineSegment) (GH-699, Martin Davis)
  * Fix DepthSegment comparison operation (GH-707, Martin Davis)
  * Add OverlayNG support for simple GeometryCollection inputs (GH-716, Martin Davis)
  * Fix TopologyPreservingSimplifier to produce stable results for Multi inputs (GH-718)
  * Fix WKB hex endian test (GH-720, Paul Ramsey)
  * Improve ConvexHull radial sort robustness (GH-724, Martin Davis)
  * Use more robust Delaunay Triangulation frame size heuristic (GH-728, Martin Davis)
* Mon Jul 18 2022 Dirk Müller <dmueller@suse.com>
- update to 3.11.0:
  OffsetCurve
  - ConcaveHull
  - PolygonHull
  - LineMerger directed option
  - CAPI: GEOSHilbertCode
  - CAPI: GEOSGeom_createRectangle
  - CAPI: GEOSGeom_transformXY
  - CAPI: GEOSRemoveRepeatedPoints
  - CAPI: GEOSLineMergeDirected
  - CAPI: setFixStructure for WKB/WKT readers to automatically repair
    structural errors in the input
  - Fix unaryUnion to avoid segfault with empty polygon
  - Fix SnapRoundingNoder to use tolerance in noding; also fixes GeometryPrecisionReducer
  - Allow direct setting of grid size
  - Allow GEOS to be used as a CMake subproject
  - Remove .inl inline files in favour of header declaration
  - Add SnappingNoder seeding
  - Add OverlayNG area check heuristic
  - Fix RelateOp
  - Fix IsValidOp to handle repeated node points
  - Fix IsSimpleOp to handle closed LineStrings with repeated endpoints
  - Fix LengthIndexedLine
  - Fix PolygonHoleJoiner
  - Improve `test_geos_unit` application error checking and reporting
  - Fix MinimumDiameter getMinimumRectangle for flat input
  - Fix BufferOp inverted ring check
  - Fix OverlayNG geomunion to avoid lines in result
* Fri Jun 17 2022 Jan Engelhardt <jengelh@inai.de>
- Rectify conflict dependencies (shlib transition from Nov 9 2015)
  against old geos.
- Update to release 3.10.3
  * VoronoiDiagramBuilder::setSites(const CoordinateSequence&)
    returns sorted output now
  * Add SnappingNoder seeding
  * Fix segfault in Hausdorff distance with empty geometries
  * Fix inf loop in PolygonTriangulator
  * Fix IsValidOp to handle repeated node points
  * Fix IsSimpleOp to handle closed LineStrings with repeated
    endpoints
  * Fix crash in GeometryNoder on empty input
* Mon Mar 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.10.2:
  * Fix crash in MonotoneChain with empty CoordinateSequence (GH-539, Sandro Santilli)
  * Fix crash in GeoJSONWriter in case of empty points (TRAC-1139, Paul Ramsey)
  * Improve BuildArea performance (TRAC-1122, Sandro Santilli)
  * Fix unaryUnion to avoid segfault with empty polygon (GH-501, Mike Taves)
  * Fix memory leak on exception in prepared geometry (GH-506, Dan Baston)
  * Iterator invalidation in rare cases (GH-508, Momtchil Momtchev)
  * Infinite loop on collapsed input to MaximumInscribedCircle (Paul Ramsey)
  * Write LinearRing to GeoJSON as LineString (TRAC-1140, Paul Ramsey)
  * Fix PolygonEarClipper to handle collapsed corners (GH-526, Martin Davis)
  * Fix GEOSSTRtree_remove for empty tree (GH-544, Dan Baston)
  * Fix crash on query of STRtree with removed items (GH-545, Dan Baston)
* Tue Dec 28 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.10.1:
  * Fix mistake in constants used to select WKB flavor in C API (GH489, Paul Ramsey)
  * Fix crash when reducing precision on a LinearRing (#1135, Paul Ramsey)
  * Fix GeoJSON crash on invalid input (GH498, Even Rouault)
  * Use std::sqrt exclusively for Solaris build (Paul Ramsey)
  * Fix mistaken version numbers in some parts of 3.10.0 (Paul Ramsey)
- Changes for version 3.10.0:
  * Preserve ordering of lines in overlay results (Martin Davis)
  * Check for invalid geometry before fixing polygonal result in Densifier
    and DPSimplifier (Martin Davis)
  * Fix overlay handling of flat interior lines (JTS-685, Martin Davis)
  * Fix IsValidOp to correctly report invalid nested MultiPolygons (#1112, Martin Davis)
  * Fix BufferOp to avoid artifacts in certain polygon buffers (#1101, Martin Davis)
  * Fix IsValidOp to correctly report certain kinds of invalid LinearRings (Martin Davis)
  * Improve STRtree performance through TemplateSTRtree implementation (Daniel Baston)
  * Fix DiscreteFrechetDistance to use initial points of input lines (#1128, Martin Davis)
  * Autoconf build system is dropped in favour of CMake
    See README.md and INSTALL.md for examples of usage
  * Libtool is no longer used for in favour of CMake
    Therefor libgeos.la is no longer built/installed
  * #1094, #1090: Drop inlines.cpp to address duplicate symbols on many platforms
    (Regina Obe)
  * GH475: Do not return NaN from GEOSProjectNormalized_r (Paul Ramsey)
  * GH442: BufferOp now returns unique_ptr<Geometry> result (Paul Ramsey)
- Drop geos-config.1
- Update project and download URL
* Tue Nov 16 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable inline to fix build on armv6/7
  https://trac.osgeo.org/geos/ticket/993
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- update to 3.9.1:
  - Windows memory management quirk in createPolygon CAPI (#1050, Paul Ramsey)
  - Allow build on Apple ARM64 (Taras Zakharko)
  - Fix buffer to use largest enclosed area for invalid rings (#732, Paul Ramsey)
  - Preserve ordering of lines in overlay results (Martin Davis)
  - Fix overlay handling of flat interior lines (JTS-685, Martin Davis)
* Thu Jan  7 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.9.0
  + New things
  - OverlayNG engine from JTS, now the default (Martin Davis, Paul Ramsey)
  - MaximumInscribedCircle and LargestEmptyCircle (JTS-530, Paul Ramsey)
  - CAPI: Fixed precision overlay operations (Sandro Santilli)
  - CAPI: GEOSPreparedNearestPoints (#1007, Sandro Santilli)
  - CAPI: GEOSPreparedDistance (#1066, Sandro Santilli)
  - CAPI: GEOSGeom_setPrecision uses OverlayNG (Paul Ramsey)
  - SimpleSTRTree spatial index implementation (Paul Ramsey)
  - Add support for pkg-config for GEOS C API (#1073, Mike Taves)
  + Improvements:
  - Stack allocate segments in OverlapUnion (Paul Ramsey)
  - Improve performance of GEOSisValid (Dan Baston)
  - Update geos-config tool for consistency
    and escape paths (https://git.osgeo.org/gitea/geos/geos/pulls/99)
    changes mostly affect CMake MSVC builds (#1015, Mike Taves)
  - Testing on Rasberry Pi 32-bit (berrie) (#1017, Bruce Rindahl, Regina Obe)
  - Replace ttmath with JTS DD double-double implementation (Paul Ramsey)
  - Fix bug in DistanceOp for geometries with empty components (#1026, Paul Ramsey)
  - Remove undefined behaviour in CAPI (#1021, Greg Troxel)
  - Fix buffering issue (#1022, JTS-525, Paul Ramsey)
  - MinimumBoundingCircle.getMaximumDiameter fix (JTS-533, Paul Ramsey)
  + Changes:
  - Drop SWIG bindings, including for Ruby and Python (#1076, Mike Taves)
- Packaging:
  + Remove ruby related package and related patch libruby.patch
  + spec-clean mini (copyright year)
* Sat May  9 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.8.1 Bug fixes / improvements
  + Stack allocate line segments in OverlapUnion (Paul Ramsey)
  + Avoid returning non-empty CoordinateSequence from empty Point
    (#1001, Dan Baston)
  + Avoid assertion failure with MSVC 2017 / 2019 (#1002, Dan Baston)
  + Remove whitespace from end of GEOSversion() output (azhi)
  + Improve performance of GEOSisValid (#1008, Dan Baston)
  + Avoid changing MultiLineString component order in GEOSReverse
    (#1013, Dan Baston)
  + Fix missing vtable for LineString and CoordinateArraySequenceFactory
    (#299 and #1016, Evgen Bodunov)
  + Reduce performance regression in GEOSBuffer (#1020)
- Use https for URL and Source
* Sat Feb  1 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.8.0
  + New things:
  - CAPI: GEOSBuildArea (#952, Even Rouault)
  - CAPI: GEOSMakeValid (#952, Even Rouault)
  - CAPI: GEOSPolygonize_valid (#727, Dan Baston)
  - CAPI: GEOSCoverageUnion (Dan Baston)
  - CAPI: GEOSCoordSeq_setXY, GEOSCoordSeq_setXYZ,
    GEOSCoordSeq_getXY, GEOSCoordSeq_getXYZ (Dan Baston)
  - CAPI: GEOSMinimumBoundingCircle (#735)
  - CAPI: GEOSGeom_createPointFromXY (Dan Baston)
  + Improvements:
  - Improve overall performance by reducing of heap allocations (Dan Baston)
  - Improve performance and robustness of GEOSPointOnSurface (Martin Davis)
  - Improve performance of GEOSPolygonize for cases with many potential
    holes (#748, Dan Baston)
  - Support extended precision calculations (ttmath) and port JTS
    improvements related to extended precision (Paul Ramsey, Mateusz Loskot)
  - Improve performance of GEOSPolygonize for cases with many or complex
    shells (Dan Baston, Martin Davis)
  - Improve performance of Delaunay triangulations / Voronoi Diagrams
    (Dan Baston)
  - Improve performance of prepared geometry operations (Dan Baston)
  - Improve robustness of Delaunay triangulations (Paul Ramsey, Martin Davis)
  - Improve performance of unary union for lines (Dan Baston)
  - Improve general predicate, overlay, and buffer performance (Dan
    Baston, Paul Ramsey)
  - Improve cascaded union performance (Paul Ramsey, Martin Davis)
  - Allocate default GeometryFactory singleton on the stack (Sandro Mani)
  - Harmonize XML tests with JTS and harmonize cmake/autoconf
    test running (Paul Ramsey)
  - CMake modernization (Mateusz Loskot, Paul Ramsey, Dan Baston)
  - Return unique_ptr from most methods that produce a new geometry (Dan Baston)
  + Changes:
  - Constructive geometry functions in CAPI now preserve SRID
    of input arguments in output (#896)
- Packaging modernize a bit the spec (minimal)
* Wed Jun 12 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.7.2
  * Envelope constructor using strtod (#875 Paul Ramsey)
  * Failure in CMake for OSX Framework (#936 Paul Ramsey)
  * Polygon build failure in Overlay difference (#789 Paul Ramsey)
  * Invalid union result from valid polygon inputs (#838)
* Mon Feb 18 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Packaging:
  + refresh patch libruby with upstream debian for 3.7.1
  + remove python as state upstream this not supported since
    version 3 (use Shapely or libgeos_c)
- Update to version 3.7.1
  + Bug fixes / improvements
  * Fix crash in GEOSCoordSeq_isCCW with empty coordseq
    (#927, Sergey Fedoseev)
  * Fix crash in GEOSInterpolate with empty LineString
    (#926, Sergey Fedoseev)
  * Fix crash in GEOSUnaryUnion with empty LineString
    (#928, Sergey Fedoseev)
  * Fix memory leak in SIRtree::insert (#919, Dan Baston)
  * Reduce required autoconf to 2.63
    (#56, John Harvey)
  * Fix incorrect return values on error from GEOSLength
    GEOSisValidDetail (#941, Dan Baston)
- Changes in 3.7.0
  + New things:
  * CAPI: GEOSDistanceIndexed (#795, Dan Baston)
  * CAPI: GEOSCoordSeq_isCCW (#870, Dan Baston)
  * CAPI: GEOSGeom_getXMin, GEOSGeom_getXMax,
    GEOSGeom_getYMin, GEOSGeom_getYMax (#871, Dan Baston)
  * CAPI: GEOSFrechetDistance (#797, Shinichi SUGIYAMA)
  * CAPI: GEOSReverse (#872, Dan Baston)
  * CAPI: GEOSGeomGetZ (#581, J Smith)
  + Improvements
  * Interruptible snap operation (Paul Ramsey)
  * Numerous packaging, doc, and build changes
    (Debian group: Bas Couwenberg, Francesco Paolo Lovergine)
    (NetBSD: Greg Troxel)
  * Allow static library with C API for CMake builds (#878, Dakota Hawkins)
  + C++ API changes:
  * Require defining USE_UNSTABLE_GEOS_CPP_API for use without
    warnings.
  * Make C++11 required (Mateusz Loskot)
  * Use C++11 unique_ptr, nullptr, and override constructs
    (Mateusz Loskot)
  * C++11 standard delete on noncopyable
    (#851, Vicky Vergara)
  * Fix CommonBits::getBit to correctly handle i >= 32
    (#834, Kurt Schwehr)
- Changes in 3.7.0rc2
  + Fixes / enhancements since 3.7.0rc1
  * Drop ? from extended regular expression,
    so that the expression strictly conforms to the POSIX ERE rules.
    (#917, Greg Troxel, Bas Couwenberg)
  * include .editorconfig in tar ball,
    fixes Cmake on VS (#920, Jeff Mckenna, Regina Obe)
  * Ignore error in CoordinateArraySequenceFactoryTest
    failing on FreeBSD/macOS Clang (#894)
- Changes in 3.7.0rc1
  + Fixes / enhancements since 3.7.0beta2
  * Avoid segfault when querying empty tree (#730, framm)
  * Collection with Empty components crashes overlay (#782, Dan Baston)
  * Allow static library with C API for CMake builds (#878, Dakota Hawkins)
- Changes in 3.7.0beta2
  + Fixes since 3.7.0beta1
  * Fix infinite loop in GEOSClipByRect (#865, Dan Baston)
  * Make GEOSException inherit from std::runtime_error
    to address clang warnings (Dan Baston)
  * Add missing CMake files to tarball (#895, Regina Obe)
* Thu Mar  8 2018 mpluskal@suse.com
- Modernise spec file a bit
* Mon Nov 13 2017 mpluskal@suse.com
- Rename python subpackage
* Mon Nov 13 2017 guillaume@opensuse.org
- Update to version 3.6.2:
  * Bug fixes / improvements:
    + Fix exception in UnaryUnion of collection of touching polygons (#837)
    + Allow building against python 3 (#774)
    + Fix build with android-ndk and other compilers (#799)
    + Allows compiling with -Wpointer-bool-conversion (#638)
    + Fix unhandled exception on invalid fp operation (#811)
    + Fix overloaded virtual print in DirectedEdge* (#812)
    + AppVeyor CI build added (#813)
    + Clean up numerous MSVC warnings, notably C4275 and C4589 (#814)
    + Bump CMake version to 3.0.0 (#817)
    + Fix leaks in WKT parser (#830)
* Mon May 29 2017 mpluskal@suse.com
- Update to version 3.6.1:
  * Bug fixes / improvements
    + Fix GEOSSTRtree_nearest_r signature and add implementation (#796)
    + Fix --static-clibs and --static-cclibs returns from geos-config
    + Fix WKB representation of empty polygon (#680).
    + Fix empty GEOSSimplify return on inner ring collapse (#741)
- Changes in 3.6.0
  * Important / Breaking Changes:
    + The PHP binding moved to its own repository:
    http://git.osgeo.org/gogs/geos/php-geos (#765)
  * New things:
    + CAPI: GEOSGeom_{get,set}UserData (Rashad Kanavath)
    + CAPI: GEOSGeom_{set,get}Precision (#713)
    + CAPI: GEOSMinimumRotatedRectangle and GEOSMinimumWidth
    (#729, Nyall Dawson)
    + CAPI: GEOSSTRtree_nearest (#768, Dan Baston)
    + CAPI: GEOSMinimumClearance and GEOSMinimumClearanceLine
    (#776, Dan Baston)
  * C++ API changes:
    + Automatic memory management for GeometryFactory objects
- Drop doc and php subpackages
- Drop no longer needed:
  * geos.ini
* Wed Dec  7 2016 bruno@ioda-net.ch
- Updated to 3.5.1 Bug fixes / improvements
  + Fix CMake configuration to allow build from released sources
    package (#753)
  + Fix memory leaks in single-sided buffers (#747), PlanarGraph
    and tests
  + Fix GeometryEditor to correctly update factory of empty
    geometries (#749)
  + Fix snapping of last segment of a closed linestring (#758)
  + Fix memory exhaustion case in isvalid (#757)
  + Fix Windows build with Visual Studio 2008 (#766)
  + Fix incorrect return from prepared multipoint intersects (#764)
  + Fix build against GCC 3.5.0+ (#784)
* Fri Jun 24 2016 mpluskal@suse.com
- Fix building with recent gcc
* Mon Nov  9 2015 mpluskal@suse.com
- Cleanups spec file with spec-cleaner
* Mon Nov  9 2015 jengelh@inai.de
- Implement shlib packaging guidelines. Drop explicit Requires,
  as the python/ruby/etc. subpackages require the libraries by
  SONAME already.
- Throw out repeated packaging of documentation
- RPM group classification corrections
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.5.0
  * Voronoi API (#627)
  * PHP: Geometry->normalize method
  * GEOS_USE_ONLY_R_API macro support (#695)
  * PHP: WKBReader->read() & WKBWriter::write() methods
  * GEOSClipByRect (#699)
  * CAPI: thread-safe message handling API (#663)
  * Speed-up intersection and difference between geometries
    with small bounding box overlap.
  * CAPI: add MULTILINESTRING support for GEOSisClosed
  * Added no-parameter CoordinateSequenceFactory::create method
- Update libruby.patch
- Remove depreciated %%py_requires macro
* Sat May 16 2015 schwab@linux-m68k.org
- Reenable tests on %%ix86
* Fri May  8 2015 mpluskal@suse.com
- Do not ship .la files
- Disable tests on no intel architectures
* Tue Feb  3 2015 mpluskal@suse.com
- Fix conditional dependecies for php and SLE-12
* Sat Jan 31 2015 mpluskal@suse.com
- Rename spec file
- Clean spec file with spec-cleaner
- Disable building of static libraries
- Remove unnecessary rpmlintrc
- Execute unit tests during build
- Build python, ruby and php bindings
* Thu Oct  3 2013 tzotsos@opensuse.org
- Update to new release  3.4.2
- Bug fixes / improvements since 3.3.8
  - Use a double for PrecisionModel scale, avoiding overflows
    should fix 32-bit regression failures (#652)
  - isnan workaround OS detection missing NetBSD, DragonFly, Sun nuance (#650)
  - Do not distribute platform.h and version.h, but install both (#601)
  - Non-standard ChangeLog file in 3.4.0 and 3.4.1 releases (#654)
  - Assertion failure snapping line to points of rectangle
    smaller than tolerance (#649)
  - Can't build using cmake with tar ball (#644)
  - Delaunay Triangulation API (#487, #565, #570, #567)
  - Interruptibility API (C and C++)
  - CAPI: GEOSNode (#496) - PHP: Geometry->node
  - GeometryPrecisionReducer class (#496, #526)
  - BufferInputLineSimplifier header exposed (#548)
  - New Centroid class supporting mixed geometry components (#612)
  - io::Writer::reserve() method
  - CAPI: GEOSNearestPoints
  - Add --cclibs, --static-clibs and --static-cclibs to geos-config (#497)
  - Early bail out of overlay exception if input is invalidation
  - New noding::GeometryNoder class
  - Added BufferOp::setSingleSided
  - Signature of most functions taking a Label changed to take it
    by reference rather than pointer.
  - Signature of most functions taking an IntersectionMatrix changed
    to take it by reference rather than pointer.
  - GraphComponent::label is now a Label value (from a pointer)
  - NodedSegmentString takes ownership of CoordinateSenuence now
  - io::Writer's toString() returns by const ref, write() takes a const ref
  - Unify prototypes of WKTReader and WKBReader constructor (#310)
  - GeometryCollection::computeEnvelopInternal and
    GeometryCollection::compareToSameClass are marked virtual (#478)
  - A point interpolated from a line does not always intersect
    the same line (#323)
  - Port ConvexHull robustness fix from JTS-1.13 (#457)
  - Improve Overlay robustness by reducing input precision on topology
    exception and by refusing to accept unnoded output (#459)
  - Improve Buffer robustness by reducing input precision on topology
    exception (#605)
  - Mismatch segment sides in OffsetCurveBuilder (#633 )
  - Fixed Linear Referencing API to handle MultiLineStrings consistently
    by always using the lowest possible index value, and by trimming
    zero-length components from results (#323)
  - Fixed CMake configuration to set correct SOVERSION (current - age)
  - Fix EMPTY return from single-point lines and zero-length polygons (#612)
  - CMakeLists.txt, tools/geos_svn_revision_cmake.h.in: Add
    geos_svn_revision.h generator to CMake config (#643)
  - Makefile.vc 'clean' step leaks obj files (#607)
  - IsValidOp: throw proper error on nested shells (#608)
  - Fix header guards (#617, #618, #619)
  - WKTWriter::appendCoordinate optimisation
  - Fix centroid computation for collections with empty components (#582)
* Thu Feb 28 2013 tzotsos@opensuse.org
  All changes since 3.3.7:
  - IsValidOp: throw proper error on nested shells (#608)
  - Fix header guards (#617, #618, #619)
  - WKTWriter::appendCoordinate optimisation
  - Fix centroid computation for collections with empty components (#582)
* Tue Jan 22 2013 tzotsos@opensuse.org
- Bug fixes / improvements
  - Fix abort in RightmostEdgeFinder (#605)
  - Do not force precision reduction below 6 significant digits
    while trying to obtain a valid Buffer output (#605)
  - Fix GEOSPointOnSurface with zero-length linestring (#609)
  - Fix EMPTY return from zero-area polygon (#613)
  - Segfault from symdifference (#615)
* Mon Nov 26 2012 tzotsos@opensuse.org
- Update to new release 3.3.6
- Bug fixes / improvements
  - Add support for testing with phpunit 3.6 (not loosing support for 3.4)
  - Segfault from intersection (#586, #598, #599)
* Mon Jun 25 2012 dassau@gbd-consult.de
- Update to new release 3.3.5
- Bug fixes / improvements
  - Correctly increment CAPI lib version from 3.3.3 (#558)
  - Port robustness fix to CentroidArea (#559)
  - Always return POINT from GEOSGetCentroid, even for EMPTY (#560)
  - Always return POINT from GEOSPointOnSurface, even for EMPTY (#561)
* Fri Jun  8 2012 dassau@gbd-consult.de
- Update to new release 3.3.4
- Bug fixes / improvementa
  - Do not abort on NaN overlay input (#530)
  - Reduce CommonBitsRemover harmful effects during overlay op (#527)
  - Better cross-compiler support (#534)
  - Enable overlay ops short-circuits (#542)
  - Envelope-based short-circuit for symDifference (#543)
  - Fix support for PHP 5.4 (#513)
  - Fix TopologyPreservingSimplifier invalid output on closed line (#508)
  - Reduce calls to ptNotInList, greatly speeding up Polygonizer (#545)
* Fri Jan  6 2012 otto.dassau@gmx.de
- Update to version 3.3.2
- Bug fixes / improvements
  - Fix CMAKE_CXX_FLAGS overriding -std=gnu++0x (#489)
  - Missing versions update in CMake configuration (#490)
  - Fix noding of self-intersecting lines through UnaryUnion (#482)
  - Fix handling of collapsed edges skipping in BufferOp (#494)
  - Print up to 18 digits of precision for TopologyException points
  - Fix noding with reduced precision in Buffer operation (#473)
  - Fix HotPixel original point invalidation (#498)
  - Fix CascadedPolygonUnion to discard non-polygonal components (#499)
  - Improve buffer robustness by reverting to non-snaprounding noder (#495)
  - Fix C++11 build by avoiding std::pair<auto_ptr> (#491)
  - Add --clibs to geos-config and GEOS_C_LIBS to geos.m4 (#497)
  - Apply shoelace formula for area calculation (#485)
  - Fix default initialization issue for clang (#500)
  - Improve overlay robustness by fixing areal validity on snapping (#488)
* Thu Jan  5 2012 otto.dassau@gmx.de
- Update to version 3.3.1
* Wed Aug 17 2011 dassau@gbd-consult.de
- added changes file
- version update to 3.3.0
  Tue Nov  9 00:00:00 UTC 2010 - Otto Dassau 3.2.2
- version update
  Thu Feb 11 00:00:00 UTC 2010 - Otto Dassau 3.2.0
- version update
  Thu Jul 30 00:00:00 UTC 2009 - Otto Dassau 3.1.1
- version update
  Mon May 18 00:00:00 UTC 2009 - Otto Dassau 3.1.0
- version update
  Sat Oct 18 00:00:00 UTC 2008 - Otto Dassau 3.0.2
- updated geos to version 3.0.2
- extended patch to fix CLocalizer.cpp gcc problem
  Thu Dec 20 00:00:00 UTC 2007 - Otto Dassau 3.0.0
- updated geos to version 3.0.0
  Tue Aug 14 00:00:00 UTC 2007 - Dirk Stöcker 2.2.3
- adapted to openSUSE BuildService
  Tue Dec 19 00:00:00 UTC 2006 - Otto Dassau 2.2.3
- adapted to SuSE 10.2
  Wed Jan 25 00:00:00 UTC 2006 - Otto Dassau 2.2.1-1
- adapted to SuSE 10.0
  Fri Dec 30 00:00:00 UTC 2005 - Shawn McCann 2.2.1-1
- Initial release for fedora fc4
